@@ -517,7 +517,7 @@ class read_configs_TestCase(testtools.TestCase):
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(read_configs_TestCase, self).setUp()
+        super().setUp()
         patch_system_interfaces(self)
         setup_config_file_fixtures(self)
 
@@ -742,7 +742,7 @@ class print_config_TestCase(testtools.TestCase):
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(print_config_TestCase, self).setUp()
+        super().setUp()
         patch_system_interfaces(self)
 
     def test_invokes_config_write_to_stdout(self):
@@ -753,7 +753,7 @@ class print_config_TestCase(testtools.TestCase):
         mock_config.write.assert_called_with(sys.stdout)
 
 
-# Copyright © 2015–2017 Ben Finney <bignose@debian.org>
+# Copyright © 2015–2019 Ben Finney <bignose@debian.org>
 #
 # This is free software: you may copy, modify, and/or distribute this work
 # under the terms of the GNU General Public License as published by the
