@@ -48,10 +48,6 @@ from .helper import (
         setup_fake_file_fixtures,
         setup_file_double_behaviour,
         )
-from .test_configfile import (
-        patch_runtime_config_options,
-        set_config,
-        )
 from .test_changesfile import (
         make_changes_document,
         make_changes_file_scenarios,
@@ -61,6 +57,10 @@ from .test_changesfile import (
         setup_changes_file_fixtures,
         setup_upload_file_fixtures,
         )
+from .test_configfile import (
+        patch_runtime_config_options,
+        set_config,
+        )
 
 
 class hexify_string_TestCase(
@@ -129,7 +129,7 @@ class checksum_test_TestCase(
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(checksum_test_TestCase, self).setUp()
+        super().setUp()
         patch_system_interfaces(self)
 
         setup_fake_file_fixtures(self)
@@ -225,7 +225,7 @@ class verify_signature_TestCase(
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(verify_signature_TestCase, self).setUp()
+        super().setUp()
         patch_system_interfaces(self)
 
         set_config(
@@ -411,7 +411,7 @@ class create_upload_file_TestCase(
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(create_upload_file_TestCase, self).setUp()
+        super().setUp()
         patch_system_interfaces(self)
 
         if not hasattr(self, 'test_host'):
@@ -529,7 +529,7 @@ class run_lintian_test_TestCase(testtools.TestCase):
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(run_lintian_test_TestCase, self).setUp()
+        super().setUp()
         patch_system_interfaces(self)
 
         patch_signal_signal(self)
@@ -654,7 +654,7 @@ class dinstall_caller_TestCase(
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(dinstall_caller_TestCase, self).setUp()
+        super().setUp()
         patch_system_interfaces(self)
 
         patch_subprocess_check_call(self)
@@ -758,7 +758,7 @@ class execute_command_TestCase(
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(execute_command_TestCase, self).setUp()
+        super().setUp()
         patch_system_interfaces(self)
 
         self.test_position = make_unique_slug(self)
@@ -852,7 +852,7 @@ class version_check_TestCase(
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(version_check_TestCase, self).setUp()
+        super().setUp()
         patch_system_interfaces(self)
 
         self.patch_dpkg_program_file()
@@ -1219,7 +1219,7 @@ class check_upload_logfile_TestCase(
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(check_upload_logfile_TestCase, self).setUp()
+        super().setUp()
         patch_system_interfaces(self)
 
         set_config(self, 'exist-simple')
@@ -1367,7 +1367,7 @@ class check_upload_logfile_ErrorTestCase(check_upload_logfile_TestCase):
         sys.exit.assert_called_with(self.expected_exit_status)
 
 
-# Copyright © 2015–2017 Ben Finney <bignose@debian.org>
+# Copyright © 2015–2019 Ben Finney <bignose@debian.org>
 #
 # This is free software: you may copy, modify, and/or distribute this work
 # under the terms of the GNU General Public License as published by the
